/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi;

import jakarta.inject.Inject;

import de.ozgcloud.zufi.pvog.PvogProcessor;
import de.ozgcloud.zufi.search.SearchService;
import io.quarkus.runtime.QuarkusApplication;
import io.quarkus.runtime.annotations.QuarkusMain;
import lombok.extern.log4j.Log4j2;

@QuarkusMain
@Log4j2
public class ZufiManagerPvogMain implements QuarkusApplication {
	private static final int ERROR = 1;

	private static final int SUCCESS = 0;

	@Inject
	PvogProcessor processor;

	@Inject
	SearchService searchService;

	@Override
	public int run(String... args) throws Exception {
		if (searchService.checkConnection() && searchService.checkIndex()) {
			try {
				processor.process();
			} catch (Exception e) {
				LOG.error("Error processing PVOG data!", e);
				return ERROR;
			}

			return SUCCESS;
		}

		return ERROR;
	}
}
