/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.metadocument;

import java.util.Date;
import java.util.Objects;
import java.util.Optional;
import java.util.UUID;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;

import de.ozgcloud.common.logging.OzgCloudLogging;
import de.ozgcloud.zufi.pvog.AntwortTransfernachricht;

@ApplicationScoped
@OzgCloudLogging
public class MetaDocumentService {
	@Inject
	MetaDocumentRepository metaDocumentRepository;

	public void saveMetaDocument(AntwortTransfernachricht transfernachricht) {
		find().ifPresentOrElse(doc -> update(updateMetaDocument(doc, transfernachricht)),
				() -> insert(updateMetaDocument(new MetaDocument(), transfernachricht)));
	}

	MetaDocument insert(MetaDocument metaDocument) {
		return metaDocumentRepository.insert(metaDocument);
	}

	MetaDocument update(MetaDocument metaDocument) {
		return metaDocumentRepository.update(metaDocument);
	}

	MetaDocument updateMetaDocument(MetaDocument doc, AntwortTransfernachricht transfernachricht) {
		var builder = doc.toBuilder().lastRead(new Date().getTime())
				.lastReadComplete(transfernachricht.vollstaendig())
				.naechsteAnfrageUrl(transfernachricht.naechsteAnfrageUrl())
				.naechsterIndex(transfernachricht.naechsterIndex());

		if (Objects.isNull(doc.getId())) {
			builder.id(UUID.randomUUID().toString());
		}

		return builder.build();
	}

	Optional<MetaDocument> find() {
		return metaDocumentRepository.find();
	}

	public Optional<Integer> findNaechsterIndex() {
		return Optional.ofNullable(metaDocumentRepository.find().map(MetaDocument::getNaechsterIndex).orElse(null));
	}
}
