/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;

import org.apache.commons.collections4.MapUtils;

import de.ozgcloud.common.logging.OzgCloudLogging;
import de.ozgcloud.zufi.common.OperationType;
import de.ozgcloud.zufi.common.PayloadType;
import de.ozgcloud.zufi.pvog.TransferOperationEntry;
import lombok.extern.log4j.Log4j2;

@ApplicationScoped
@OzgCloudLogging
@Log4j2
public class OrganisationsEinheitService {

	@Inject
	OrganisationsEinheitMapper mapper;

	@Inject
	OrganisationsEinheitRepository repository;

	void insert(TransferOperationEntry entry) {
		if (isValid(entry)) {
			repository.upsert(mapper.mapPayload(entry.getPayload()));
		} else {
			LOG.info("Entry {} is invalid and will be ignored.", entry);
		}
	}

	void delete(TransferOperationEntry loescheObjekt) {
		repository.delete(loescheObjekt.getPayload().get(TransferOperationEntry.ID_FIELD));
	}

	boolean isValid(TransferOperationEntry entry) {
		if (MapUtils.isEmpty(entry.getPayload())) {
			return false;
		}

		return PayloadType.ORGANISATIONSEINHEIT.equals(entry.getPayloadType()) && OperationType.WRITE.equals(entry.getOperationType());
	}

	public void process(TransferOperationEntry entry) {
		if (OperationType.WRITE.equals(entry.getOperationType())) {
			insert(entry);
		} else if (OperationType.DELETE.equals(entry.getOperationType())) {
			delete(entry);
		} else {
			LOG.info("Unkown OperationType recieved, ignoring it");
		}
	}
}
