/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.pvog;

import java.time.Duration;
import java.util.Optional;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;
import jakarta.ws.rs.core.MultivaluedHashMap;
import jakarta.ws.rs.core.MultivaluedMap;

import org.eclipse.microprofile.rest.client.ext.ClientHeadersFactory;

import io.quarkus.oidc.client.NamedOidcClient;
import io.quarkus.oidc.client.OidcClient;
import io.quarkus.oidc.client.Tokens;
import lombok.extern.log4j.Log4j2;

@ApplicationScoped
@Log4j2
public class AuthTokenHeaderFactory implements ClientHeadersFactory {
	static final String AUTHORIZATION = "Authorization: ";
	static final String BEARER = "Bearer ";

	@Inject
	@NamedOidcClient("kop")
	OidcClient client;

	@Override
	public MultivaluedMap<String, String> update(MultivaluedMap<String, String> incomingHeaders,
			MultivaluedMap<String, String> clientOutgoingHeaders) {
		MultivaluedMap<String, String> result = new MultivaluedHashMap<>();

		addAuthTokenToHeader(result);

		return result;
	}

	private void addAuthTokenToHeader(MultivaluedMap<String, String> result) {
		var token = getAuthToken();

		token.ifPresentOrElse(jwt -> result.add(AUTHORIZATION, BEARER + jwt), () -> LOG.warn("No oidc auth token received"));
	}

	public Optional<String> getAuthToken() {
		Optional<Tokens> tokens = client.getTokens().await().asOptional().atMost(Duration.ofSeconds(10));

		return tokens.map(oauthTokens -> Optional.of(oauthTokens.getAccessToken())).orElse(Optional.empty());
	}

}
