/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.pvog;

import java.io.StringReader;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;

import org.apache.commons.lang3.StringUtils;
import org.eclipse.microprofile.config.inject.ConfigProperty;
import org.eclipse.microprofile.rest.client.inject.RestClient;

import de.ozgcloud.common.logging.OzgCloudLogging;
import de.ozgcloud.zufi.schema.TransferOperation040502;

@ApplicationScoped
@OzgCloudLogging
class PvogService {
	static final String NO_OR_EMPTY_DATA_RECEIVED_FROM_PVOG_SERVICE = "No or empty data received from PVOG Service";

	@RestClient
	PvogRemoteService remoteService;

	@ConfigProperty(name = "ozgcloud.zufi.land.code", defaultValue = "01%")
	String bundesLandCode;

	@Inject
	TransferOperationMapper mapper;

	AntwortTransfernachricht getAllVerwaltungsObjekte() {
		return getIncrementVerwaltungsObjekte(0);
	}

	AntwortTransfernachricht getIncrementVerwaltungsObjekte(int index) {
		return remoteService.getVerwaltungsObjekte(index, bundesLandCode);
	}

	TransferOperation parseXml(String xzufiObjekte) throws JAXBException {
		var jaxbUnmarshaller = JAXBContext.newInstance("de.ozgcloud.zufi.schema").createUnmarshaller();

		return mapper.mapTo((TransferOperation040502) jaxbUnmarshaller.unmarshal(new StringReader(xzufiObjekte)));
	}

	boolean dataAvailable(AntwortTransfernachricht transfernachricht) {
		return StringUtils.isNotEmpty(transfernachricht.xzufiObjekte());
	}

	boolean hasMoreData(AntwortTransfernachricht transfernachricht) {
		return !transfernachricht.vollstaendig();
	}
}
