/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.pvog;

import jakarta.ws.rs.core.Response;
import jakarta.ws.rs.ext.Provider;

import org.eclipse.microprofile.rest.client.ext.ResponseExceptionMapper;

import de.ozgcloud.common.errorhandling.TechnicalException;

@Provider
public class RemoteServiceExceptionMapper implements ResponseExceptionMapper<TechnicalException> {
	static final String HTTP_5XX_ERROR = "The remote service responded with an error. Code HTTP ";

	static final String HTTP_4XX_ERROR = "Error using the remote service. Code HTTP ";

	@Override
	public TechnicalException toThrowable(Response response) {
		if (response.getStatus() >= 500) {
			return new TechnicalException(HTTP_5XX_ERROR + response.getStatus());
		} else if (response.getStatus() >= 400 && response.getStatus() < 499) {
			return new TechnicalException(HTTP_4XX_ERROR + response.getStatus());
		}

		return null;
	}

}
