/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.search;

import java.io.IOException;
import java.util.Objects;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;

import org.eclipse.microprofile.config.inject.ConfigProperty;

import de.ozgcloud.common.logging.OzgCloudLogging;
import lombok.extern.log4j.Log4j2;

@ApplicationScoped
@OzgCloudLogging
@Log4j2
public class SearchService {
	@Inject
	SearchIndexRepository searchIndexRepository;

	@ConfigProperty(name = "ozgcloud.zufi.index.name", defaultValue = "zufi-manager")
	String indexName;

	public boolean checkConnection() throws IOException {
		return Objects.nonNull(searchIndexRepository.checkConnection());
	}

	public boolean checkIndex() {
		try {
			searchIndexRepository.checkIndex();
			return true;
		} catch (IOException e) {
			LOG.error("Index %s is missing.".formatted(indexName), e);
			return false;
		}
	}
}
