/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.common.errorhandling.TechnicalException;
import de.ozgcloud.zufi.pvog.PvogProcessor;
import de.ozgcloud.zufi.search.SearchService;
import lombok.SneakyThrows;

class ZufiManagerPvogMainTest {
	@Spy
	@InjectMocks
	ZufiManagerPvogMain main;
	@Mock
	PvogProcessor processor;
	@Mock
	SearchService searchService;

	@DisplayName("Test starting the PvogProcessor")
	@Nested
	class TestRun {

		@DisplayName("if elasticsearch is available")
		@Nested
		class WhenElasticsearchAvailable {
			@BeforeEach
			@SneakyThrows
			void init() {
				when(searchService.checkConnection()).thenReturn(true);
				when(searchService.checkIndex()).thenReturn(true);
			}

			@Test
			@SneakyThrows
			void shouldCallProcessorProcess() {
				main.run();

				verify(processor).process();
			}

			@DisplayName("check return status")
			@Nested
			class CheckStatus {
				@Test
				@SneakyThrows
				void shouldReturnOneOnError() {
					doThrow(TechnicalException.class).when(processor).process();

					assertThat(main.run()).isEqualTo(1);
				}

				@Test
				@SneakyThrows
				void shouldReturnZero() {
					assertThat(main.run()).isZero();
				}
			}
		}

		@DisplayName("if elasticsearch is not available")
		@Nested
		class WhenElasticsearchNotAvailable {
			@Test
			@SneakyThrows
			void shouldNotStartBecauseNoConnection() {
				when(searchService.checkConnection()).thenReturn(false);

				main.run();

				verify(processor, never()).process();
			}

			@Test
			@SneakyThrows
			void shouldNotStartBecauseNoIndex() {
				when(searchService.checkConnection()).thenReturn(true);
				when(searchService.checkIndex()).thenReturn(false);

				main.run();

				verify(processor, never()).process();
			}
		}
	}
}
