/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.common.errorhandling;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.UUID;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.Spy;

import com.thedeanda.lorem.LoremIpsum;

class ApiErrorUtilTest {

	@Spy
	private final ApiErrorUtil util = new ApiErrorUtil();

	private final String message = LoremIpsum.getInstance().getWords(5);
	private final String exceptionId = UUID.randomUUID().toString();

	@DisplayName("Build from runtime exception")
	@Nested
	class TestBuildFromRuntimeException {

		private static final String UUID_PATTERN = "[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}";
		private final RuntimeException exception = new RuntimeException(message);

		@BeforeEach
		void mockExceptionId() {
			doReturn(exceptionId).when(util).createExceptionId();
		}

		@Test
		void shouldHaveMessageCode() {
			var error = handleException();

			assertThat(error.getIssues()).hasSize(1);
			assertThat(error.getIssues().get(0).getMessageCode()).isEqualTo(ApiErrorUtil.RUNTIME_MESSAGE_CODE);
		}

		@Test
		void shouldHaveMessage() {
			var error = handleException();

			assertThat(error.getIssues()).hasSize(1);
			assertThat(error.getIssues().get(0).getMessage()).contains(exception.getMessage());
			assertThat(error.getIssues().get(0).getMessage()).contains(exceptionId);
		}

		@Test
		void shouldHaveExceptionId() {
			var error = handleException();

			assertThat(error.getIssues()).hasSize(1);
			assertThat(error.getIssues().get(0).getExceptionId()).isEqualTo(exceptionId);
		}

		@Test
		void shouldCreateId() {
			var id = util.createExceptionId();

			assertThat(id).isNotNull().matches(UUID_PATTERN);
		}

		private ApiError handleException() {
			return util.buildFromRuntimeException(exception);
		}
	}
}