/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.pvog;

import static de.ozgcloud.zufi.pvog.AuthTokenHeaderFactory.*;
import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.Optional;

import jakarta.ws.rs.core.MultivaluedMap;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import io.quarkus.oidc.client.OidcClient;
import io.quarkus.oidc.client.Tokens;
import io.smallrye.mutiny.Uni;

class AuthTokenHeaderFactoryTest {
	private static final String TOKEN = "token";

	@Spy
	@InjectMocks
	AuthTokenHeaderFactory authTokenHeaderFactory;

	@Mock
	OidcClient oidcClient;

	@DisplayName("Test adding auth header")
	@Nested
	class TestAddingTokenToHeaders {
		@Mock
		MultivaluedMap<String, String> incomingHeaders;

		@Mock
		MultivaluedMap<String, String> outgoingHeaders;

		@Test
		void shouldUpdateHeaders() {
			doReturn(Optional.of(TOKEN)).when(authTokenHeaderFactory).getAuthToken();

			var headers = authTokenHeaderFactory.update(incomingHeaders, outgoingHeaders);

			assertThat(headers.get(AUTHORIZATION)).contains(BEARER + TOKEN);
		}
	}

	@DisplayName("Test loading auth token")
	@Nested
	class TestLoadingAuthToken {
		@Mock
		Tokens tokens;

		@Test
		void shouldGetToken() {
			when(tokens.getAccessToken()).thenReturn(TOKEN);
			when(oidcClient.getTokens()).thenReturn(Uni.createFrom().item(tokens));

			var token = authTokenHeaderFactory.getAuthToken();

			assertThat(token).isPresent().get().isEqualTo(TOKEN);
		}
	}
}
