/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.pvog;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import jakarta.ws.rs.core.Response;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

class RemoteServiceExceptionMapperTest {
	@Spy
	@InjectMocks
	RemoteServiceExceptionMapper exceptionMapper;

	@Mock
	Response response;

	@DisplayName("Test mapping the incomming error response")
	@Nested
	class TestResponseMapping {
		@Test
		void shouldMap5xxError() {
			when(response.getStatus()).thenReturn(500);

			var exception = exceptionMapper.toThrowable(response);

			assertThat(exception.getMessage()).contains(RemoteServiceExceptionMapper.HTTP_5XX_ERROR + "500");
		}

		@Test
		void shouldMap4xxError() {
			when(response.getStatus()).thenReturn(400);

			var exception = exceptionMapper.toThrowable(response);

			assertThat(exception.getMessage()).contains(RemoteServiceExceptionMapper.HTTP_4XX_ERROR + "400");
		}

		@Test
		void shouldNotMapError() {
			when(response.getStatus()).thenReturn(200);

			var exception = exceptionMapper.toThrowable(response);

			assertThat(exception).isNull();
		}
	}

}
