/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.pvog;

import static de.ozgcloud.zufi.pvog.TransferOperationEntry.*;

import java.util.Map;
import java.util.UUID;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.zufi.common.OperationType;
import de.ozgcloud.zufi.common.PayloadType;

public class TransferOperationEntryTestFactory {
	public static final String ID = UUID.randomUUID().toString();
	public static final String ORGANISATIONSEINHEIT_NAME = LoremIpsum.getInstance().getName();
	public static final String ORGANISATIONSEINHEIT_BEZIRK = LoremIpsum.getInstance().getStateAbbr();
	public static final String ORGANISATIONSEINHEIT_BUNDESLAND = LoremIpsum.getInstance().getStateFull();
	public static final String ORGANISATIONSEINHEIT_GEMEINDESCHLUESSEL = LoremIpsum.getInstance().getZipCode();
	public static final String ORGANISATIONSEINHEIT_GEMEINDETEILSCHLUESSEL = LoremIpsum.getInstance().getZipCode();
	public static final String ORGANISATIONSEINHEIT_KREIS = LoremIpsum.getInstance().getCity();
	public static final PayloadType ORGANISATIONSEINHEIT_PAYLOAD_TYPE = PayloadType.ORGANISATIONSEINHEIT;
	public static final String ORGANISATIONSEINHEIT_REGIONALSCHLUESSEL = LoremIpsum.getInstance().getZipCode();

	public static TransferOperationEntry createWriteOrganisationsEinheitEntry() {
		return createBuilder()
				.operationType(OperationType.WRITE)
				.payloadType(ORGANISATIONSEINHEIT_PAYLOAD_TYPE)
				.payload(Map.of(
						ID_FIELD, ID,
						ORGANISATIONSEINHEIT_NAME_FIELD, ORGANISATIONSEINHEIT_NAME,
						ORGANISATIONSEINHEIT_BEZIRK_FIELD, ORGANISATIONSEINHEIT_BEZIRK,
						ORGANISATIONSEINHEIT_BUNDESLAND_FIELD, ORGANISATIONSEINHEIT_BUNDESLAND,
						ORGANISATIONSEINHEIT_GEMEINDESCHLUESSEL_FIELD, ORGANISATIONSEINHEIT_GEMEINDESCHLUESSEL,
						ORGANISATIONSEINHEIT_GEMEINDETEILSCHLUESSEL_FIELD, ORGANISATIONSEINHEIT_GEMEINDETEILSCHLUESSEL,
						ORGANISATIONSEINHEIT_KREIS_FIELD, ORGANISATIONSEINHEIT_KREIS,
						ORGANISATIONSEINHEIT_REGIONALSCHLUESSEL_FIELD, ORGANISATIONSEINHEIT_REGIONALSCHLUESSEL))
				.build();
	}

	public static TransferOperationEntry createDeleteEntry() {
		return createBuilder().operationType(OperationType.DELETE).build();
	}

	public static TransferOperationEntry.TransferOperationEntryBuilder createBuilder() {
		return TransferOperationEntry.builder().payload(Map.of(ID_FIELD, ID));
	}
}
