/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.search;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.io.IOException;

import org.elasticsearch.client.Request;
import org.elasticsearch.client.ResponseException;
import org.elasticsearch.client.RestClient;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import lombok.SneakyThrows;

class SearchIndexRepositoryTest {

	@Spy
	@InjectMocks
	SearchIndexRepository searchIndexRepository;

	@Mock
	RestClient restClient;

	@DisplayName("Test the connection to the search server")
	@Nested
	class TestConnection {
		@Test
		@SneakyThrows
		void shouldCheck() {
			searchIndexRepository.checkConnection();

			verify(restClient).performRequest(any(Request.class));
		}

		@Test
		@SneakyThrows
		void shouldCheckError() {
			when(restClient.performRequest(any())).thenThrow(ResponseException.class);

			assertThatExceptionOfType(IOException.class).isThrownBy(() -> searchIndexRepository.checkConnection());
		}
	}

	@DisplayName("Test the index")
	@Nested
	class TestIndex {
		@Test
		@SneakyThrows
		void shouldCheck() {
			searchIndexRepository.checkIndex();

			verify(restClient).performRequest(any(Request.class));
		}

		@Test
		@SneakyThrows
		void shouldCheckError() {
			when(restClient.performRequest(any())).thenThrow(ResponseException.class);

			assertThatExceptionOfType(IOException.class).isThrownBy(() -> searchIndexRepository.checkIndex());
		}
	}
}
