/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.search;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.io.IOException;

import org.elasticsearch.client.Response;
import org.elasticsearch.client.ResponseException;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.springframework.test.util.ReflectionTestUtils;

import lombok.SneakyThrows;

class SearchServerTest {
	private static final String INDEX_NAME = "zufi-manager";

	@Spy
	@InjectMocks
	SearchService searchService;

	@Mock
	SearchIndexRepository indexRepository;

	@BeforeEach
	void init() {
		ReflectionTestUtils.setField(searchService, "indexName", INDEX_NAME);
	}

	@DisplayName("Test the search service availibility")
	@Nested
	class TestSearchServiceAvailibility {
		@Mock
		Response response;

		@DisplayName("check the connection to the search service")
		@Nested
		class CheckConnection {
			@BeforeEach
			void init() throws IOException {
				when(indexRepository.checkConnection()).thenReturn(response);
			}

			@Test
			@SneakyThrows
			void shouldCheckConnection() {
				searchService.checkConnection();

				verify(indexRepository).checkConnection();
			}
		}

		@DisplayName("check the search index ")
		@Nested
		class CheckSearchIndex {

			@Test
			@SneakyThrows
			void shouldCallCheckIndex() {
				searchService.checkIndex();

				verify(indexRepository).checkIndex();
			}
		}
	}

	@DisplayName("Test when the the search service is not availibility")
	@Nested
	class TestSearchServiceUnavailibility {
		@DisplayName("check the exception when checking for the index")
		@Nested
		class CheckIndex {
			@Test
			@SneakyThrows
			void shouldReturnFalseOnError() {
				when(indexRepository.checkIndex()).thenThrow(ResponseException.class);

				assertThat(searchService.checkIndex()).isFalse();
			}
		}

	}
}
