/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import java.io.IOException;
import java.util.Map;

import org.elasticsearch.ElasticsearchStatusException;
import org.elasticsearch.action.DocWriteResponse.Result;
import org.elasticsearch.action.update.UpdateRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Repository;

import de.ozgcloud.common.errorhandling.TechnicalException;
import lombok.extern.log4j.Log4j2;

@Repository
@Log4j2
class OrganisationsEinheitCustomRepositoryImpl implements OrganisationsEinheitCustomRepository {

	@Value("${ozgcloud.zufi.index.name:zufi-manager}")
	private String indexName;

	@Autowired
	private ElasticsearchClientFacade elasticsearchFacade;

	@Override
	public boolean updateServiceAddress(String organisationsEinheitId, String serviceAddress) {
		try {
			var result = elasticsearchFacade.update(
					new UpdateRequest()
							.doc(Map.of(VORGANG_MANAGER_ADDRESS_FIELD, serviceAddress))
							.id(organisationsEinheitId)
							.index(indexName))
					.getResult();

			return Result.UPDATED.equals(result) || Result.NOOP.equals(result);

		} catch (IOException e) {
			var message = "IOException when updating OrganisationsEinheit with id %s in index %s".formatted(organisationsEinheitId, indexName);
			LOG.error(message, e);
			throw new TechnicalException(message, e);
		} catch (ElasticsearchStatusException e) {
			LOG.error("ElasticsearchStatusException when updating OrganisationsEinheit with id %s. The maybe the id does not exist in index %s"
					.formatted(organisationsEinheitId, indexName), e);
			return false;
		}
	}
}
