/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import java.util.stream.Stream;

import org.springframework.beans.factory.annotation.Autowired;

import de.ozgcloud.zufi.grpc.registration.GrpcVorgangManagerRegistrationRequest;
import de.ozgcloud.zufi.grpc.registration.GrpcVorgangManagerRegistrationResponse;
import de.ozgcloud.zufi.grpc.registration.VorgangManagerRegistrationServiceGrpc.VorgangManagerRegistrationServiceImplBase;
import io.grpc.stub.StreamObserver;
import net.devh.boot.grpc.server.service.GrpcService;

@GrpcService
public class VorgangManagerRegistrationGrpcService extends VorgangManagerRegistrationServiceImplBase {
	@Autowired
	private OrganisationsEinheitService service;

	@Override
	public void register(GrpcVorgangManagerRegistrationRequest request, StreamObserver<GrpcVorgangManagerRegistrationResponse> responseObserver) {
		registerAddress(request.getServiceAddress(), getOrganisationeEinheiten(request));

		responseObserver.onNext(GrpcVorgangManagerRegistrationResponse.newBuilder().setSuccess(true).build());

		responseObserver.onCompleted();
	}

	private Stream<String> getOrganisationeEinheiten(GrpcVorgangManagerRegistrationRequest request) {
		return request.getOrganisationsEinheitenIdsList().stream();
	}

	private void registerAddress(String address, Stream<String> organsisationsEinheiten) {
		organsisationsEinheiten.forEach(id -> service.updateVorgangManagerAddress(address, id));
	}
}
