/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi;

import java.time.Duration;

import org.springframework.boot.test.util.TestPropertyValues;
import org.springframework.context.ApplicationContextInitializer;
import org.springframework.context.ConfigurableApplicationContext;
import org.testcontainers.containers.wait.strategy.Wait;
import org.testcontainers.elasticsearch.ElasticsearchContainer;
import org.testcontainers.utility.DockerImageName;

import lombok.extern.log4j.Log4j2;

@Log4j2
public class SearchTestInitializer implements ApplicationContextInitializer<ConfigurableApplicationContext> {
	private static final String ELASTICSEARCH_IMAGE = "docker.elastic.co/elasticsearch/elasticsearch";
	private static final String ELASTICSEARCH_VERSION = "8.3.2";

	private static ElasticsearchContainer elasticsearchContainer;

	private final static String PASSWORD = "sUpers3cret!";
	private static final String USERNAME = "elastic";

	@Override
	public void initialize(ConfigurableApplicationContext applicationContext) {
		initContainer();

		setProperties(elasticsearchContainer, applicationContext);
	}

	@SuppressWarnings("resource")
	private void initContainer() {
		if (elasticsearchContainer == null) {
			LOG.info("Creating elasticsearchContainer ...");
			elasticsearchContainer = new ElasticsearchContainer(DockerImageName.parse(ELASTICSEARCH_IMAGE).withTag(ELASTICSEARCH_VERSION))
					.withPassword(PASSWORD);
			elasticsearchContainer.getEnvMap().put("xpack.security.enabled", "false");
		}

		if (!elasticsearchContainer.isRunning()) {
			LOG.info("Starting elasticsearchContainer ...");
			elasticsearchContainer.setWaitStrategy(
					Wait.forLogMessage(".*message\":\"started.*", 1).withStartupTimeout(Duration.ofMinutes(3)));
			elasticsearchContainer.start();
			LOG.info("ecs started");
		}
	}

	protected void setProperties(ElasticsearchContainer container, ConfigurableApplicationContext applicationContext) {
		var uriString = String.format("http://%s:%d", container.getHost(), container.getFirstMappedPort());
		LOG.info("Uri: {} ", uriString);

		TestPropertyValues.of(
				"spring.elasticsearch.uris= http://" + container.getHost() + ":" + container.getFirstMappedPort(),
				"spring.elasticsearch.username= " + USERNAME,
				"spring.elasticsearch.password= " + PASSWORD).applyTo(applicationContext);
	}
}
