/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.Mock;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.boot.test.mock.mockito.SpyBean;
import org.springframework.test.annotation.DirtiesContext;

import de.ozgcloud.common.test.ITCase;
import de.ozgcloud.zufi.grpc.registration.GrpcVorgangManagerRegistrationResponse;
import io.grpc.stub.StreamObserver;

@ITCase
@DirtiesContext
class VorgangManagerRegistrationGrpcServiceITCase {
	@DisplayName("Test registering a vorgangmanager and the organsiationseinheiten he is responsible for")
	@Nested
	class TestRegisterGrpcService {
		@Autowired
		private VorgangManagerRegistrationGrpcService grpcService;

		@SpyBean
		private OrganisationsEinheitService organisationsEinheitService;

		@Mock
		private StreamObserver<GrpcVorgangManagerRegistrationResponse> responseObserver;

		@MockBean
		private OrganisationsEinheitCustomRepository repository;

		@Test
		void shouldRegister() {
			when(repository.updateServiceAddress(anyString(), anyString())).thenReturn(true);

			grpcService.register(GrpcVorgangManagerRegistrationTestFactory.createRequest(), responseObserver);

			verify(organisationsEinheitService, times(2)).updateVorgangManagerAddress(anyString(), anyString());
		}
	}
}
