/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import static de.ozgcloud.zufi.organisationseinheit.GrpcVorgangManagerRegistrationTestFactory.*;
import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.ArgumentCaptor;
import org.mockito.Captor;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.zufi.grpc.registration.GrpcVorgangManagerRegistrationResponse;
import io.grpc.stub.StreamObserver;

class VorgangManagerRegistrationGrpcServiceTest {
	@DisplayName("Test gRPC registration service")
	@Nested
	class TestRegistrationGrpcService {
		@Spy
		@InjectMocks
		private VorgangManagerRegistrationGrpcService vorgangManagerRegistrationGrpcService;

		@Mock
		private OrganisationsEinheitService service;

		@Mock
		private StreamObserver<GrpcVorgangManagerRegistrationResponse> responseObserver;

		@Captor
		private ArgumentCaptor<GrpcVorgangManagerRegistrationResponse> responseCaptor;

		@Test
		void shouldCallService() {
			vorgangManagerRegistrationGrpcService.register(GrpcVorgangManagerRegistrationTestFactory.createRequest(), responseObserver);

			verify(service, times(ORGANISATIONS_EINHEITEN_IDS.size())).updateVorgangManagerAddress(anyString(), anyString());
		}

		@Test
		void shouldReturnStatus() {
			vorgangManagerRegistrationGrpcService.register(GrpcVorgangManagerRegistrationTestFactory.createRequest(), responseObserver);

			verify(responseObserver).onNext(responseCaptor.capture());
			assertThat(responseCaptor.getValue().getSuccess()).isTrue();
		}
	}
}
